@@ -12,7 +12,7 @@ package MooX::Options::Role;
 use strict;
 use warnings;
 
-our $VERSION = '3.84';    # VERSION
+our $VERSION = '3.85';    # VERSION
 
 use MRO::Compat;
 use Moo::Role;
@@ -60,6 +60,17 @@ sub parse_options {
         return $cmdline_name;
     };
 
+    my %format_doc = (
+        's'  => ' String',
+        's@' => '[Strings]',
+        'i'  => ' Int',
+        'i@' => '[Ints]',
+        'o'  => ' Ext. Int',
+        'o@' => '[Ext. Ints]',
+        'f'  => ' Real',
+        'f@' => '[Reals]',
+    );
+
     my %has_to_split;
     for my $name (
         sort {
@@ -72,6 +83,11 @@ sub parse_options {
         my %data = %{ $options_data{$name} };
         my $doc  = $data{doc};
         $doc = "no doc for $name" if !defined $doc;
+        my $format_doc_str = $data{format} // ' None';
+        $format_doc_str = $format_doc{$format_doc_str}
+            if defined $format_doc{$format_doc_str};
+        $doc = "( " . sprintf( "%-11s", $format_doc_str ) . " ), " . $doc;
+
         push @options, [ $option_name->( $name, %data ), $doc ];
         if ( defined $data{autosplit} ) {
             $has_to_split{"--${name}"}
@@ -179,7 +195,7 @@ MooX::Options::Role - role that is apply to your object
 
 =head1 VERSION
 
-version 3.84
+version 3.85
 
 =head1 METHODS
 
